<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="si">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="374"/>
        <source>Cannot generate random number by TPM</source>
        <translation>Cannot generate random number by TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="377"/>
        <source>No available encrypt algorithm.</source>
        <translation>No available encrypt algorithm.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="380"/>
        <source>TPM encrypt failed.</source>
        <translation>TPM encrypt failed.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="383"/>
        <source>TPM is locked.</source>
        <translation>TPM is locked.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="411"/>
        <source>Confirm encrypt %1?</source>
        <translation>Confirm encrypt %1?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="414"/>
        <source>The current partition is about to be encrypted and cannot be canceled during the encryption process, please confirm the encryption.</source>
        <translation>The current partition is about to be encrypted and cannot be canceled during the encryption process, please confirm the encryption.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="421"/>
        <source>* After encrypting the partition, the system cannot be rolled back to a lower version, please confirm the encryption</source>
        <translation>* After encrypting the partition, the system cannot be rolled back to a lower version, please confirm the encryption</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="432"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="433"/>
        <source>Confirm and Reboot</source>
        <translation>Confirm and Reboot</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="434"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="444"/>
        <source>Decrypt %1?</source>
        <translation>Decrypt %1?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="445"/>
        <source>Decryption can take a long time, so make sure power is connected until the decryption is complete.</source>
        <translation>Decryption can take a long time, so make sure power is connected until the decryption is complete.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::ChgPassphraseDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="18"/>
        <source>passphrase</source>
        <translation>passphrase</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="20"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="109"/>
        <source>Recovery key</source>
        <translation>Recovery key</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="171"/>
        <source>Validate with %1</source>
        <translation>Validate with %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="172"/>
        <source>Please input recovery key</source>
        <translation>Please input recovery key</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="174"/>
        <source>Old %1</source>
        <translation>Old %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="70"/>
        <source>New %1</source>
        <translation>New %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="56"/>
        <source>Modify %1</source>
        <translation>Modify %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="67"/>
        <source>Please enter %1 again</source>
        <translation>Please enter %1 again</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="71"/>
        <source>Repeat %1</source>
        <translation>Repeat %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="77"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="78"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="101"/>
        <source>%1 cannot be empty</source>
        <translation>'%1 cannot be empty'</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>Recovery key is not valid!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="140"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="145"/>
        <source>%1 inconsistency</source>
        <translation>'%1 inconsistency'</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="177"/>
        <source>Validate with recovery key</source>
        <translation>Validate with recovery key</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DecryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>Validate with %1</source>
        <translation>Validate with %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="56"/>
        <source>Please input %1 to decrypt device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="103"/>
        <source>Decrypt device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="51"/>
        <source>Please input recovery key to decrypt device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="57"/>
        <source>Validate with recovery key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="79"/>
        <source>Passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="81"/>
        <source>Recovery key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="82"/>
        <source>%1 cannot be empty!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="87"/>
        <source>Recovery key is not valid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="111"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DiskEncryptMenuScene</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="148"/>
        <source>Unlock encrypted partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="152"/>
        <source>Cancel partition encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="156"/>
        <source>passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="157"/>
        <source>Changing the encryption %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="161"/>
        <source>Continue partition encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="165"/>
        <source>Continue partition decryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="169"/>
        <source>Enable partition encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="225"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="226"/>
        <source>Cannot resolve passphrase from TPM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="248"/>
        <source>PIN error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="276"/>
        <source>Change passphrase failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="525"/>
        <source>Unlock device failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="526"/>
        <source>Wrong passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="544"/>
        <source>Mount device failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>unmount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="588"/>
        <source>Encrypt failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="589"/>
        <source>Cannot %1 device %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="673"/>
        <source>Reboot to continue encrypt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="674"/>
        <source>Reboot to finish decrypt</source>
        <translation>නිවේදනය කරන ලද දුරුවා අවසන් කරන්න</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="130"/>
        <source>Unlocked by passphrase</source>
        <translation>පාස්වර්ඩ් විසින් අක්‍රමණය කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="157"/>
        <source>In special cases such as forgetting the password or the encryption hardware is damaged, you can decrypt the encrypted partition with the recovery key, please export it to a non-encrypted partition and keep it in a safe place!</source>
        <translation>පාස්වර්ඩ් අසාමාන්‍ය කාර්යයක් විසින් අක්‍රමණය කරන්න හෝ අක්‍රමණ මෙහෙයුම් යුතු දේහය අසාමාන්‍ය විය හැකි අවස්ථාවක, ඔබ අක්‍රමණය කරන දුරුවාව අක්‍රමණය කරන්න සඳහා අවසන් කිරීමේ ප්‍රමාණය මගින් අක්‍රමණය කරන්න, එය අක්‍රමණ දුරුවාවක හෝ ප්‍රමාණයක ස්ථානගත කරන්න සහ එය අවම අවසන් කරන්න!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="172"/>
        <source>Please select a non-encrypted partition as the key file export path.</source>
        <translation>කේ අක්‍රමණය කරන්න මගින් ප්‍රමාණයක් ස්ථානගත කරන්න අවම අක්‍රමණය කරන්න.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="192"/>
        <source>Passphrase</source>
        <translation>පාස්වර්ඩ්</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="194"/>
        <source>%1 cannot be empty</source>
        <translation>'%1 අවම අඩංගු නොවේ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="225"/>
        <source>%1 inconsistency</source>
        <translation>'%1 අසාමාන්‍යතාවය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="236"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation>අවසන් කිරීමේ ප්‍රමාණය අවම අඩංගු නොවේ!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="241"/>
        <source>Recovery key export path is not exists!</source>
        <translation>අවසන් කිරීමේ ප්‍රමාණය අසාමාන්‍ය නොවේ!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="248"/>
        <source>Please export to an external device such as a non-encrypted partition or USB flash drive.</source>
        <translation>කේ අක්‍රමණය කරන්න මගින් ප්‍රමාණයක් හෝ USB flash drive මගින් අවම අක්‍රමණය කරන්න අවම අඩංගු කරන්න.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="253"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation>මෙම ප්‍රමාණය අභ්‍යෝග්‍ය නොවේ, ඔබ අභ්‍යෝග්‍ය ප්‍රමාණයක අවම අඩංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="265"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation>මෙම ප්‍රමාණය අක්‍රමණය කරන්න, ඔබ අක්‍රමණ දුරුවාවක හෝ USB flash drive මගින් අවම අඩංගු කරන්න.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="421"/>
        <source>TPM is locked and cannot be used for partition encryption. Please cancel the TPM password or choose another unlocking method.</source>
        <translation>TPM අක්‍රමණය කරන්න සහ අක්‍රමණ දුරුවාවක ස්ථානගත කරන්න. ඔබ TPM පාස්වර්ඩ් අවම අඩංගු කරන්න හෝ අනෙකුවක් අක්‍රමණය කරන්න ලද අවස්ථාවක අවම අඩංගු කරන්න.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="423"/>
        <source>TPM error</source>
        <translation>TPM අඩංගු අවශ්‍යතාවය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="426"/>
        <source>TPM status error!</source>
        <translation>TPM අවස්ථාව අඩංගු අවශ්‍යතාවය!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Next</source>
        <translation>මෙහෙයුම් අවම අඩංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="316"/>
        <source>Please continue to encrypt partition %1</source>
        <translation>මෙම ප්‍රමාණය අක්‍රමණය කරන්න %1 අවම අඩංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="321"/>
        <source>Previous</source>
        <translation>පෙර අවම අඩංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="320"/>
        <source>Export Recovery Key</source>
        <translation>අවසන් කිරීමේ ප්‍රමාණය අවම අඩංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="329"/>
        <source>Set %1</source>
        <translation>%1 අවම අඩංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="330"/>
        <source>Repeat %1</source>
        <translation>%1 අවම අඩංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="336"/>
        <source>passphrase</source>
        <translation>පාස්වර්ඩ්</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="340"/>
        <source>Access to the partition will be unlocked using a passphrase.</source>
        <translation>මෙම ප්‍රමාණය අක්‍රමණය කරන්න සඳහා ඔබ පාස්වර්ඩ් භාවිතා කරන්න.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="347"/>
        <source>Access to the partition will be unlocked using the TPM security chip and PIN.</source>
        <translation>මෙම ප්‍රමාණය අක්‍රමණය කරන්න සඳහා ඔබ TPM ආරක්‍ෂා ප්‍රමාණය සහ PIN භාවිතා කරන්න.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="350"/>
        <source>Access to the partition will be automatically unlocked using the TPM security chip, no passphrase checking is required.</source>
        <translation>මෙම ප්‍රමාණය අක්‍රමණය කරන්න සඳහා TPM ආරක්‍ෂා ප්‍රමාණය භාවිතා කරන්න, ඔබ පාස්වර්ඩ් සැකසූ අවස්ථාවක අවම අඩංගු කරන්න.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="332"/>
        <source>Please enter the %1 again</source>
        <translation>%1 අවම අඩංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="110"/>
        <source>Unlock type</source>
        <translation>අක්‍රමණ අවස්ථාව</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="131"/>
        <source>Use TPM+PIN to unlock on this computer (recommended)</source>
        <translation>මෙම අභ්‍යෝග්‍ය ප්‍රමාණය සඳහා TPM+PIN භාවිතා කරන්න (අදහස් විය හැකි)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="132"/>
        <source>Automatic unlocking on this computer by TPM</source>
        <translation>මෙම අභ්‍යෝග්‍ය ප්‍රමාණය සඳහා TPM භාවිතා කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="220"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation>අවම 8 අක්‍රමණ මෙහෙයුම් ප්‍රමාණයක්, A-Z, a-z, 0-9 සහ අක්‍රමණ මෙහෙයුම් ප්‍රමාණයක් අඩංගු වේ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Confirm encrypt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="343"/>
        <source>PIN</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptProgressDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="54"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="63"/>
        <source>Re-export the recovery key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="67"/>
        <source>*Recovery key saving failed, please re-save the recovery key to a non-encrypted partition and keep it in a safe place!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="82"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="143"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="148"/>
        <source>Recovery key export path is not exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="154"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="167"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="183"/>
        <source>Cannot create recovery key file!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EventsHandler</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="424"/>
        <source>Preencrypt done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="425"/>
        <source>Device %1 has been preencrypt, please reboot to finish encryption.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="431"/>
        <source>Preencrypt failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="432"/>
        <source>Device %1 preencrypt failed, please see log for more information.(%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="460"/>
        <source>Wrong passpharse or PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="496"/>
        <source>passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="499"/>
        <source>PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="506"/>
        <source>Change %1 done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="507"/>
        <source>%1's %2 has been changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="512"/>
        <source>Change %1 failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="513"/>
        <source>Wrong %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="518"/>
        <source>Device %1 change %2 failed, please see log for more information.(%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="180"/>
        <source>Encrypt done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="181"/>
        <source>Device %1 has been encrypted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="185"/>
        <source>Encrypt failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="186"/>
        <source>Device %1 encrypt failed, please see log for more information.(%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="285"/>
        <source>%1 is under encrypting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="286"/>
        <source>The encrypting process may have system lag, please minimize the system operation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="305"/>
        <source>%1 is under decrypting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="306"/>
        <source>The decrypting process may have system lag, please minimize the system operation</source>
        <translation>විකල්ප කර්මාන්තය ප්‍රමාණිත ප්‍රමාණයක් ඇති අතර, ප්‍රමාණය අඩු කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>Error</source>
        <translation>අඩු අභියෝගය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="452"/>
        <source>Decrypt done</source>
        <translation>විකල්ප කළ තිබේ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="453"/>
        <source>Device %1 has been decrypted</source>
        <translation>වේදිකා %1 විකල්ප කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="459"/>
        <source>Decrypt disk</source>
        <translation>වේදිකා විකල්ප කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="463"/>
        <source>Decrypt failed</source>
        <translation>විකල්ප සාර්ථක නොවිය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="464"/>
        <source>Device %1 is under encrypting, please decrypt after encryption finished.</source>
        <translation>වේදිකා %1 විකල්ප කරන්න, විකල්ප අවසන් වූ පසු විකල්ප කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="469"/>
        <source>Device %1 Decrypt failed, please see log for more information.(%2)</source>
        <translation>වේදිකා %1 විකල්ප සාර්ථක නොවිය, ඔබ ප්‍රමාණය අවලඟන්න අතර විශේෂ අවශ්‍යතා සඳහා ලෝග් අවලඟන්න(%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="547"/>
        <source>Device is not fully decrypted, please finish decryption before access.</source>
        <translation>වේදිකා ප්‍රමාණිත විකල්ප නොවිය, ප්‍රාවේදනය සාර්ථක වූ පසු අවධිය අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="554"/>
        <source>Unlocking device failed</source>
        <translation>වේදිකා අඩු කිරීම සාර්ථක නොවිය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="555"/>
        <source>Please click the right disk menu "Continue partition encryption" to complete partition encryption.</source>
        <translation>ප්‍රාවේදනය කරන්න සඳහා වේදිකා ප්‍රමාණයෙහි ප්‍රමාණිත මිනිත්තුව </translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>TPM status is abnormal, please use the recovery key to unlock it</source>
        <translation>TPM අවස්ථා අසාර්ථක විය, ඔබ අවලඟන්න සඳහා ප්‍රතික්‍රියා ප්‍රමාණය භාවිතා කරන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="357"/>
        <source>Wrong PIN</source>
        <translation>අදුරු ප්‍රමාණය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="359"/>
        <source>Wrong passphrase</source>
        <translation>අදුරු ප්‍රමාණය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="361"/>
        <source>TPM error</source>
        <translation>TPM අපෝහය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="363"/>
        <source>Please use recovery key to unlock device.</source>
        <translation>වේදිකා අවලඟන්න සඳහා ප්‍රතික්‍රියා ප්‍රමාණය භාවිතා කරන්න.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::UnlockPartitionDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="51"/>
        <source>Cancel</source>
        <translation>අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="52"/>
        <source>Unlock</source>
        <translation>අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="81"/>
        <source>Unlock encryption partition</source>
        <translation>අවලඟන්න ප්‍රාවේදනය ප්‍රමාණය</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="85"/>
        <source>Unlock by recovery key</source>
        <translation>ප්‍රතික්‍රි‍යා ප්‍රමාණය සමග අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="90"/>
        <source>Unlock by passphrase</source>
        <translation>ප්‍රමාණය සමග අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="91"/>
        <source>Unlock by PIN</source>
        <translation>ප්‍රමාණය සමග අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="93"/>
        <source>Please input recovery key to unlock device</source>
        <translation>වේධිකා අවලඟන්න සඳහා ප්‍රතික්‍රියා ප්‍රමාණය ඇති අවධිය ඇති අවධිය අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="99"/>
        <source>Please input passphrase to unlock device</source>
        <translation>වේධිකා අවලඟන්න සඳහා ප්‍රමාණය ඇති අවධිය අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="102"/>
        <source>Please input PIN to unlock device</source>
        <translation>වේධිකා අවලඟන්න සඳහා ප්‍රමාණය ඇති අවධිය අවලඟන්න</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>ප්‍රතික්‍රියා ප්‍රමාණය සාර්ථක නොවිය!</translation>
    </message>
</context>
</TS>
